@@ -46,7 +46,9 @@ class Adder:
         )
         project_root = Path(repo.working_dir)
 
-        if not template.path.is_absolute() and not (config_path.parent.resolve() == Path(os.getcwd())):
+        if not template.path.is_absolute() and not (
+            config_path.parent.resolve() == Path(os.getcwd())
+        ):
             # Relative path, if the config output location is different than the
             # current directory, need to adjust the path to be relative to
             # the config output location
@@ -54,7 +56,9 @@ class Adder:
             # Don't overwrite existing template
             template = deepcopy(template)
             # Make template path relative to its config file rather than current directory
-            template.path = Path(os.path.relpath(template.path.resolve(), config_path.parent.resolve()))
+            template.path = Path(
+                os.path.relpath(template.path.resolve(), config_path.parent.resolve())
+            )
 
         if add_mode == AddMode.USER:
             # No need to use git if adding for user
@@ -147,13 +151,13 @@ class Adder:
             - 1,
             data=data,
         )
-
         updater.update(
             repo,
             [template_update],
             merged_branch_name=merged_branch_name,
             template_branch_name=template_branch_name,
             no_input=no_input,
+            full_rerender=False,
             renderer=renderer,
             config_manager=config_manager,
         )
