@@ -36,6 +36,7 @@ class Updater:
         merged_branch_name: str = DEFAULT_MERGED_BRANCH_NAME,
         template_branch_name: str = DEFAULT_TEMPLATE_BRANCH_NAME,
         no_input: bool = False,
+        full_rerender: bool = True,
         renderer: MultiRenderer = MultiRenderer(),
         config_manager: ConfigManager = ConfigManager(),
     ):
@@ -50,15 +51,27 @@ class Updater:
         # Create it from the initial commit if it does not exist
         cwd = Path(os.getcwd())
         with temp_repo_that_pushes_to_branch(  # type: ignore
-            repo, branch_name=template_branch_name, delete_tracked_files=True
+            repo, branch_name=template_branch_name, delete_tracked_files=full_rerender
         ) as temp_repo:
             temp_out_path = Path(temp_repo.working_dir)  # type: ignore
             temp_updates = _move_update_config_locations_to_new_parent(
                 updates, out_path, temp_out_path
             )
-            config_manager.update_templates(temp_updates, project_root=temp_out_path)
+            # On first update, don't use template source path. This means that
+            # the template paths will be absolute, so they can be loaded even though we are
+            # working in a temp directory
+            config_manager.update_templates(
+                temp_updates, project_root=temp_out_path, use_template_source_path=False
+            )
+            orig_renderables = (
+                config_manager.get_all_renderables(project_root=temp_out_path)
+                if full_rerender
+                else config_manager.get_renderables_for_updates(
+                    updates, project_root=out_path
+                )
+            )
             renderables = _move_renderable_out_roots_to_new_parent(
-                config_manager.get_renderables(project_root=temp_out_path),
+                orig_renderables,
                 out_path,
                 temp_out_path,
             )
@@ -69,7 +82,16 @@ class Updater:
             updated_data = renderer.render(
                 renderables, project_root=temp_out_path, no_input=no_input
             )
-            new_updates = updates_with_updated_data(temp_updates, updated_data)
+            new_updates = updates_with_updated_data(
+                temp_updates,
+                updated_data,
+                renderables,
+                project_root=out_path,
+                render_root=temp_out_path,
+            )
+            # On second update, use template source path. This means that it will set the template
+            # paths back to how they were originally (relative if needed), so that there will not be
+            # unexpected changes from relative to absolute paths in the user configs
             config_manager.update_templates(new_updates, project_root=temp_out_path)
             stage_and_commit_all(temp_repo, _commit_message(renderables))
 
@@ -120,24 +142,24 @@ class Updater:
         finder: MultiFinder = MultiFinder(),
         config_manager: ConfigManager = ConfigManager(),
     ):
-        sources = config_manager.get_sources_for_templates(
+        sources_with_templates = config_manager.get_sources_with_templates(
             templates, project_root=project_root
         )
-        templates_by_name = {template.name: template for template in templates}
-        for source in sources:
+        for source_with_templates in sources_with_templates:
             # TODO: Separate finding from updating the local version of the repo
             #  If the code failed after the find line but before updating the config,
             #  then the config would not match what is on the disk
+            source = source_with_templates.source
             kwargs: Dict[str, Any] = {}
             if source.target_version:
                 kwargs.update(version=source.target_version)
-            new_template = finder.find(str(source.update_location), **kwargs)
-            template = templates_by_name[source.name]
-            if template.version != new_template.version:
-                # Template needs to be upgraded
-                # As finder already updates the local files, just update the template object
-                template.version = new_template.version
-                template.path = new_template.path
+            for template in source_with_templates.templates:
+                new_template = finder.find(str(source.update_location), **kwargs)
+                if template.version != new_template.version:
+                    # Template needs to be upgraded
+                    # As finder already updates the local files, just update the template object
+                    template.version = new_template.version
+                    template.path = new_template.path
 
 
 def _commit_message(renderables: Sequence[Renderable]) -> str:
