@@ -17,7 +17,7 @@ from tests.config import (
     COOKIECUTTER_REMOTE_VERSION_2,
 )
 from tests.fixtures.git import *
-from tests.fixtures.subdir_style import SubdirStyle, subdir_style
+from tests.fixtures.subdir_style import SubdirStyle, subdir_style, subdir_style_or_none
 from tests.fixtures.template import (
     CookiecutterRemoteTemplateData,
     get_header_for_cookiecutter_remote_template,
@@ -31,7 +31,9 @@ from tests.fixtures.template_source import (
     TemplateSourceFixture,
     template_source,
     template_source_one_remote_and_all_local_relative,
+    template_source_with_relative,
     TemplateSourceType,
+    COOKIECUTTER_REMOTE_DEFAULT_EXPECT_PATH,
 )
 
 
@@ -61,6 +63,7 @@ def test_init_project_and_add_source_and_template(
         version=template_source.default_version,
         name=template_source.name,
         url=template_source.url,
+        path=template_source.expect_path(),
     )
 
     project_config_path = GENERATED_REPO_DIR / "flexlate-project.json"
@@ -137,14 +140,24 @@ def test_init_project_and_add_source_and_template_in_subdir(
         applied_config_dir = subdir
         expect_applied_template_root = Path(".")
         template_sources_config_dir = GENERATED_REPO_DIR
+        expect_template_source_path = template_source.expect_path()
     elif add_mode == AddMode.PROJECT:
         applied_config_dir = GENERATED_REPO_DIR
         expect_applied_template_root = subdir.relative_to(GENERATED_REPO_DIR)
         template_sources_config_dir = GENERATED_REPO_DIR
+        expect_template_source_path = template_source.expect_path()
     elif add_mode == AddMode.USER:
         applied_config_dir = GENERATED_FILES_DIR
         expect_applied_template_root = subdir.absolute()
         template_sources_config_dir = GENERATED_FILES_DIR
+        if template_source.is_local_template:
+            # Move the original directory down a level in the relative path
+            # E.g. move ../../input_files/templates/cookiecutters/one to ../input_files/templates/cookiecutters/one
+            expect_template_source_path = str(
+                Path(*Path(template_source.expect_path()).parts[1:])
+            )
+        else:
+            expect_template_source_path = template_source.expect_path()
     else:
         raise ValueError(f"unsupported add mode {add_mode}")
 
@@ -153,6 +166,7 @@ def test_init_project_and_add_source_and_template_in_subdir(
         version=template_source.default_version,
         name=template_source.name,
         url=template_source.url,
+        path=expect_template_source_path,
     )
     _assert_applied_templates_config_is_correct(
         applied_config_dir / "flexlate.json",
@@ -168,86 +182,138 @@ def test_init_project_and_add_source_and_template_in_subdir(
     )
 
 
+@pytest.mark.parametrize("update_from_subdir", [False, True])
 def test_update_project(
+    update_from_subdir: bool,
     flexlates: FlexlateFixture,
     repo_with_placeholder_committed: Repo,
-    template_source: TemplateSourceFixture,
+    template_source_with_relative: TemplateSourceFixture,
 ):
     fxt = flexlates.flexlate
-    no_input = flexlates.type == FlexlateType.APP
     repo = repo_with_placeholder_committed
+    template_source = template_source_with_relative
+
+    no_input = flexlates.type == FlexlateType.APP
+    subdir = GENERATED_REPO_DIR / "subdir1" / "subdir2"
+    subdir.mkdir(parents=True)
+
+    def assert_root_template_output_is_correct(
+        after_version_update: bool = False, after_data_update: bool = False
+    ):
+        version = (
+            template_source.version_2
+            if after_version_update
+            else template_source.version_1
+        )
+        input_data = (
+            template_source.update_input_data
+            if after_data_update
+            else template_source.input_data
+        )
+        _assert_project_files_are_correct(
+            expect_data=input_data,
+            version=version,
+            template_source_type=template_source.type,
+        )
+        _assert_config_is_correct(
+            expect_data=input_data,
+            version=version,
+            template_source_type=template_source.type,
+            name=template_source.name,
+            url=template_source.url,
+            path=template_source.expect_path(version),
+        )
+
+    def assert_subdir_template_output_is_correct(
+        after_version_update: bool = False, after_data_update: bool = False
+    ):
+        version = (
+            template_source.version_2
+            if after_version_update
+            else template_source.version_1
+        )
+        input_data = (
+            template_source.update_input_data
+            if after_data_update
+            else template_source.input_data
+        )
+        _assert_project_files_are_correct(
+            subdir,
+            expect_data=input_data,
+            version=version,
+            template_source_type=template_source.type,
+        )
+        _assert_applied_templates_config_is_correct(
+            subdir / "flexlate.json",
+            expect_applied_template_root=Path("."),
+            expect_data=input_data,
+            version=version,
+            template_source_type=template_source.type,
+            name=template_source.name,
+        )
+        _assert_template_sources_config_is_empty(subdir / "flexlate.json")
+
     with change_directory_to(GENERATED_REPO_DIR):
         fxt.init_project()
         fxt.add_template_source(
             template_source.path, target_version=template_source.version_1
         )
+        # Add an output in the main directory
         fxt.apply_template_and_add(
             template_source.name, data=template_source.input_data, no_input=no_input
         )
-        _assert_project_files_are_correct(
-            expect_data=template_source.input_data,
-            version=template_source.version_1,
-            template_source_type=template_source.type,
-        )
-        _assert_config_is_correct(
-            expect_data=template_source.input_data,
-            version=template_source.version_1,
-            template_source_type=template_source.type,
-            name=template_source.name,
-            url=template_source.url,
-        )
+        assert_root_template_output_is_correct()
 
-        # First update does nothing, because version is at target version
-        # When using app, it will throw an error
-        if flexlates.type == FlexlateType.APP:
-            with pytest.raises(GitCommandError) as excinfo:
+        # Add an output of the same template source in a subdirectory
+        with change_directory_to(subdir):
+            fxt.apply_template_and_add(
+                template_source.name, data=template_source.input_data, no_input=no_input
+            )
+            assert_subdir_template_output_is_correct()
+
+        update_directory = subdir if update_from_subdir else GENERATED_REPO_DIR
+        with change_directory_to(update_directory):
+            # First update does nothing, because version is at target version
+            # When using app, it will throw an error
+            if flexlates.type == FlexlateType.APP:
+                with pytest.raises(GitCommandError) as excinfo:
+                    fxt.update(no_input=True)
+                assert "Your branch is up to date" in str(excinfo.value)
+            else:
+                # When using CLI, it will not throw an error, just display the message
                 fxt.update(no_input=True)
-            assert "Your branch is up to date" in str(excinfo.value)
-        else:
-            # When using CLI, it will not throw an error, just display the message
+
+            assert_root_template_output_is_correct()
+            assert_subdir_template_output_is_correct()
+
+            # Now update by just passing new data, should change the output
+            # even though the version has not changed
+            fxt.update(data=[template_source.update_input_data] * 2, no_input=no_input)
+            assert_root_template_output_is_correct(after_data_update=True)
+            assert_subdir_template_output_is_correct(after_data_update=True)
+
+            # Now update the target version
+            # TODO: replace with cli command to update target version once it exists
+            config_path = GENERATED_REPO_DIR / "flexlate.json"
+            config = FlexlateConfig.load(config_path)
+            source = config.template_sources[0]
+            source.target_version = template_source.version_2
+            config.save()
+            stage_and_commit_all(
+                repo, "Update target version for cookiecutter to version 2"
+            )
+
+            # Make changes to update local templates to new version (no-op for remote templates)
+            template_source.version_migrate_func(template_source.url_or_absolute_path)
+
+            # Now update should go to new version
             fxt.update(no_input=True)
 
-        _assert_project_files_are_correct(
-            expect_data=template_source.input_data,
-            version=template_source.version_1,
-            template_source_type=template_source.type,
-        )
-        _assert_config_is_correct(
-            expect_data=template_source.input_data,
-            version=template_source.version_1,
-            template_source_type=template_source.type,
-            name=template_source.name,
-            url=template_source.url,
-        )
-
-        # Now update the target version
-        # TODO: replace with cli command to update target version once it exists
-        config_path = GENERATED_REPO_DIR / "flexlate.json"
-        config = FlexlateConfig.load(config_path)
-        source = config.template_sources[0]
-        source.target_version = template_source.version_2
-        config.save()
-        stage_and_commit_all(
-            repo, "Update target version for cookiecutter to version 2"
-        )
-
-        # Make changes to update local templates to new version (no-op for remote templates)
-        template_source.version_migrate_func(template_source.path)
-
-        # Now update should go to new version
-        fxt.update(no_input=True)
-
-    _assert_project_files_are_correct(
-        expect_data=template_source.input_data,
-        template_source_type=template_source.type,
-        version=template_source.version_2,
+    assert_root_template_output_is_correct(
+        after_version_update=True, after_data_update=True
     )
-    _assert_config_is_correct(
-        expect_data=template_source.input_data,
-        version=template_source.version_2,
-        template_source_type=template_source.type,
-        name=template_source.name,
-        url=template_source.url,
+    assert_subdir_template_output_is_correct(
+        after_version_update=True, after_data_update=True
     )
 
     project_config_path = GENERATED_REPO_DIR / "flexlate-project.json"
@@ -357,6 +423,7 @@ def _assert_template_sources_config_is_correct(
     version: str = COOKIECUTTER_REMOTE_VERSION_2,
     name: str = COOKIECUTTER_REMOTE_NAME,
     url: str = COOKIECUTTER_REMOTE_URL,
+    path: str = COOKIECUTTER_REMOTE_DEFAULT_EXPECT_PATH,
 ):
     assert config_path.exists()
     config = FlexlateConfig.load(config_path)
@@ -366,6 +433,7 @@ def _assert_template_sources_config_is_correct(
     assert template_source.name == name
     assert template_source.version == version
     assert template_source.git_url == url
+    assert template_source.path == path
 
 
 def _assert_template_sources_config_is_empty(
@@ -412,6 +480,7 @@ def _assert_config_is_correct(
     template_source_type: TemplateSourceType = TemplateSourceType.COOKIECUTTER_REMOTE,
     name: str = COOKIECUTTER_REMOTE_NAME,
     url: str = COOKIECUTTER_REMOTE_URL,
+    path: str = COOKIECUTTER_REMOTE_DEFAULT_EXPECT_PATH,
 ):
     _assert_applied_templates_config_is_correct(
         config_path,
@@ -422,7 +491,7 @@ def _assert_config_is_correct(
         name=name,
     )
     _assert_template_sources_config_is_correct(
-        config_path, version=version, name=name, url=url
+        config_path, version=version, name=name, url=url, path=path
     )
 
 
